##Change Log

###Version 1.1.7
* Fix for https://github.com/siddii/angular-timer/issues/29 (start-time doesn't work in combination with autostart)

###Version 1.1.6
* Added countdown finished callback - https://github.com/siddii/angular-timer/pull/64

###Version 1.1.5
* Fix for - https://github.com/siddii/angular-timer/issues/84

###Version 1.1.4
* CommonJS Compliance - https://github.com/siddii/angular-timer/pull/80

###Version 1.1.3
* Setting `countdownattr` value on `tick` - https://github.com/siddii/angular-timer/pull/78

###Version 1.1.2
* Countdown time max-time-unit for month & year - https://github.com/siddii/angular-timer/pull/74

###Version 1.1.1
* Fix for https://github.com/siddii/angular-timer/issues/73

###Version 1.1.0
* Plural/singular units. PR - https://github.com/siddii/angular-timer/pull/54
* IE8 support. PR - https://github.com/siddii/angular-timer/pull/62

###Version 1.0.12
* `clear` method. Please see this PR - https://github.com/siddii/angular-timer/pull/43

###Version 1.0.11
* `addCDSeconds` method for running countdown timer

###Version 1.0.10
* Minor bug fixes - https://github.com/siddii/angular-timer/issues/33

###Version 1.0.9
* `end-time` attribute

###Version 1.0.8
* Fixing the broken stuff in the last version

###Version 1.0.7
* Ignore `bower_components` folder - https://github.com/siddii/angular-timer/issues/30
* Templates doesn't work with angular 1.2.0 - https://github.com/siddii/angular-timer/issues/29

###Version 1.0.6
* Removing `node_modules` folder. Fix for - https://github.com/siddii/angular-timer/issues/26

###Version 1.0.5
* Performance Optimization. Please see - https://github.com/siddii/angular-timer/pull/25

###Version 1.0.4
* 'auto-start' attribute name change to 'autostart' in support of Angular 1.2. See #14

###Version 1.0.3
* Successful Bower integration!
